@@ -9,10 +9,14 @@
     unused_qualifications,
     warnings
 )]
-// ---
-// #![no_std] if the standard library is not present.
 #![cfg_attr(not(feature = "std"), no_std)]
 
+#[cfg(feature = "std")]
+extern crate core;
+
+#[cfg(feature = "alloc")]
+extern crate alloc;
+
 #[macro_use]
 extern crate tracing;
 
@@ -26,15 +30,16 @@ pub use ockam_node_attribute::*;
 // ---
 
 // Export node implementation
-#[cfg(all(feature = "std", feature = "ockam_node"))]
+#[cfg(feature = "std")]
 pub use ockam_node::*;
 
-#[cfg(all(not(feature = "std"), feature = "ockam_node_no_std"))]
+#[cfg(not(feature = "std"))]
 pub use ockam_node_no_std::*;
 // ---
 
 mod delay;
 mod error;
+mod forwarder;
 mod lease;
 mod monotonic;
 mod protocols;
@@ -43,7 +48,9 @@ mod unique;
 
 pub use delay::*;
 pub use error::*;
+pub use forwarder::*;
 pub use lease::*;
+pub use ockam_core::compat;
 pub use ockam_core::worker;
 pub use ockam_entity::*;
 pub use protocols::*;
